@@ -8,3 +8,5 @@ directsum(a::AbstractOperator...) = reduce(directsum, a)
 ptrace(a::AbstractOperator, index) = arithmetic_unary_error("Partial trace", a)
 _index_complement(b::CompositeBasis, indices) = complement(length(b.bases), indices)
 reduced(a, indices) = ptrace(a, _index_complement(basis(a), indices))
+commutator(A::AbstractOperator, B::AbstractOperator) = A*B - B*A
+anticommutator(A::AbstractOperator, B::AbstractOperator) = A*B + B*A
